// java wrapper for vtkHyperTree object
//

package vtk;
import vtk.*;

public class vtkHyperTree extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native int GetNumberOfLevels_3();
  public int GetNumberOfLevels()
    { return GetNumberOfLevels_3(); }

  private native int GetNumberOfVertices_4();
  public int GetNumberOfVertices()
    { return GetNumberOfVertices_4(); }

  private native int GetNumberOfNodes_5();
  public int GetNumberOfNodes()
    { return GetNumberOfNodes_5(); }

  private native int GetNumberOfLeaves_6();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_6(); }

  private native int GetBranchFactor_7();
  public int GetBranchFactor()
    { return GetBranchFactor_7(); }

  private native int GetDimension_8();
  public int GetDimension()
    { return GetDimension_8(); }

  private native int GetNumberOfChildren_9();
  public int GetNumberOfChildren()
    { return GetNumberOfChildren_9(); }

  private native void SetScale_10(double id0[]);
  public void SetScale(double id0[])
    { SetScale_10(id0); }

  private native void GetScale_11(double id0[]);
  public void GetScale(double id0[])
    { GetScale_11(id0); }

  private native double GetScale_12(int id0);
  public double GetScale(int id0)
    { return GetScale_12(id0); }

  private native long CreateInstance_13(int id0,int id1);
  public vtkHyperTree CreateInstance(int id0,int id1) {
    long temp = CreateInstance_13(id0,id1);

    if (temp == 0) return null;
    return (vtkHyperTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long NewCursor_14();
  public vtkHyperTreeCursor NewCursor() {
    long temp = NewCursor_14();

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SubdivideLeaf_15(vtkHyperTreeCursor id0);
  public void SubdivideLeaf(vtkHyperTreeCursor id0)
    { SubdivideLeaf_15(id0); }

  private native int GetActualMemorySize_16();
  public int GetActualMemorySize()
    { return GetActualMemorySize_16(); }

  private native void SetGlobalIndexStart_17(int id0);
  public void SetGlobalIndexStart(int id0)
    { SetGlobalIndexStart_17(id0); }

  private native void SetGlobalIndexFromLocal_18(int id0,int id1);
  public void SetGlobalIndexFromLocal(int id0,int id1)
    { SetGlobalIndexFromLocal_18(id0,id1); }

  private native int GetGlobalIndexFromLocal_19(int id0);
  public int GetGlobalIndexFromLocal(int id0)
    { return GetGlobalIndexFromLocal_19(id0); }

  public vtkHyperTree() { super(); }

  public vtkHyperTree(long id) { super(id); }

}
